@@ -19,14 +19,23 @@ def init(creds_path_, sheet_name_, worksheet_idx_=0):
     global sheet_name
     global worksheet_idx
     global gc
-    global sheet
     global sno
     global worksheet 
     global column_idx
 
     creds_path = creds_path_
     sheet_name = sheet_name_
-    worksheet_idx = worksheet_idx_
+    worksheet_idx = worksheet_idx_      
+
+    gc = pygsheets.authorize(service_file=creds_path) 
+    sheet = gc.open(sheet_name)
+    worksheet = sheet[worksheet_idx]
+
+def log_data(offset=0, increment_cols=True, verify_timeout=None, **kwargs):
+    global sno 
+    global column_idx
+    global worksheet 
+    global sno_logged       
 
     gc = pygsheets.authorize(service_file=creds_path) 
     sheet = gc.open(sheet_name)
@@ -34,12 +43,6 @@ def init(creds_path_, sheet_name_, worksheet_idx_=0):
     sno = get_sno(worksheet)
     column_idx = 1 
 
-def log_data(offset=0, increment_cols=True, **kwargs):
-    global sno 
-    global column_idx
-    global worksheet 
-    global sno_logged
-
     if not sno_logged:
         sno_logged = True
         assert('sno' not in kwargs.keys())
@@ -54,4 +57,23 @@ def log_data(offset=0, increment_cols=True, **kwargs):
     worksheet.set_dataframe(df, (sno + 1, column_idx + offset), copy_head=False)
 
     if increment_cols:
-        column_idx += len(kwargs) + offset
\ No newline at end of file
+        column_idx += len(kwargs) + offset  
+
+    if verify_timeout: 
+        print("Verifying data logged")
+        start_time = time.time()    
+        
+        while time.time() - start_time < verify_timeout:
+            gc = pygsheets.authorize(service_file=creds_path) 
+            sheet = gc.open(sheet_name)
+            worksheet = sheet[worksheet_idx]
+
+            if sno + 1 == get_sno(worksheet):
+                print("Data logged successfully")
+                return True
+            else: 
+                print("Data not logged yet, retrying in 0.1s")
+
+            time.sleep(0.1) 
+        
+        raise Exception("Data not logged in time")
